# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pipeline/pipeline/v1beta/component_definition.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from pipeline.pipeline.v1beta import common_pb2 as pipeline_dot_pipeline_dot_v1beta_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3pipeline/pipeline/v1beta/component_definition.proto\x12\x18pipeline.pipeline.v1beta\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a%pipeline/pipeline/v1beta/common.proto\"\xbe\r\n\x13\x43omponentDefinition\x12\x17\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\x15\n\x03uid\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x03uid\x12\x13\n\x02id\x18\x03 \x01(\tB\x03\xe0\x41\x05R\x02id\x12\x19\n\x05title\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x05title\x12\x30\n\x11\x64ocumentation_url\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x10\x64ocumentationUrl\x12\x17\n\x04icon\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x04icon\x12K\n\x04spec\x18\x07 \x01(\x0b\x32\x32.pipeline.pipeline.v1beta.ComponentDefinition.SpecB\x03\xe0\x41\x03R\x04spec\x12@\n\x04type\x18\x08 \x01(\x0e\x32\'.pipeline.pipeline.v1beta.ComponentTypeB\x03\xe0\x41\x03R\x04type\x12!\n\ttombstone\x18\t \x01(\x08\x42\x03\xe0\x41\x03R\ttombstone\x12\x1b\n\x06public\x18\n \x01(\x08\x42\x03\xe0\x41\x03R\x06public\x12\x1b\n\x06\x63ustom\x18\x0b \x01(\x08\x42\x03\xe0\x41\x03R\x06\x63ustom\x12\x1b\n\x06vendor\x18\x0c \x01(\tB\x03\xe0\x41\x03R\x06vendor\x12I\n\x11vendor_attributes\x18\r \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x10vendorAttributes\x12\"\n\nsource_url\x18\x0e \x01(\tB\x03\xe0\x41\x03R\tsourceUrl\x12\x1d\n\x07version\x18\x0f \x01(\tB\x03\xe0\x41\x03R\x07version\x12\x42\n\x05tasks\x18\x10 \x03(\x0b\x32\'.pipeline.pipeline.v1beta.ComponentTaskB\x03\xe0\x41\x03R\x05tasks\x12%\n\x0b\x64\x65scription\x18\x11 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x64\n\rrelease_stage\x18\x12 \x01(\x0e\x32:.pipeline.pipeline.v1beta.ComponentDefinition.ReleaseStageB\x03\xe0\x41\x03R\x0creleaseStage\x12\x45\n\x06\x65vents\x18\x13 \x03(\x0b\x32(.pipeline.pipeline.v1beta.ComponentEventB\x03\xe0\x41\x03R\x06\x65vents\x1a\xd0\x04\n\x04Spec\x12U\n\x17\x63omponent_specification\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x16\x63omponentSpecification\x12\x80\x01\n\x13\x64\x61ta_specifications\x18\x05 \x03(\x0b\x32J.pipeline.pipeline.v1beta.ComponentDefinition.Spec.DataSpecificationsEntryB\x03\xe0\x41\x03R\x12\x64\x61taSpecifications\x12\x83\x01\n\x14\x65vent_specifications\x18\x06 \x03(\x0b\x32K.pipeline.pipeline.v1beta.ComponentDefinition.Spec.EventSpecificationsEntryB\x03\xe0\x41\x03R\x13\x65ventSpecifications\x1ar\n\x17\x44\x61taSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32+.pipeline.pipeline.v1beta.DataSpecificationR\x05value:\x02\x38\x01\x1at\n\x18\x45ventSpecificationsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.pipeline.pipeline.v1beta.EventSpecificationR\x05value:\x02\x38\x01\";\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\r\n\tVIEW_FULL\x10\x02\"\xbc\x01\n\x0cReleaseStage\x12\x1d\n\x19RELEASE_STAGE_UNSPECIFIED\x10\x00\x12\'\n#RELEASE_STAGE_OPEN_FOR_CONTRIBUTION\x10\x01\x12\x1d\n\x19RELEASE_STAGE_COMING_SOON\x10\x02\x12\x17\n\x13RELEASE_STAGE_ALPHA\x10\x03\x12\x16\n\x12RELEASE_STAGE_BETA\x10\x04\x12\x14\n\x10RELEASE_STAGE_GA\x10\x05\"}\n\x11\x44\x61taSpecification\x12\x32\n\x05input\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x05input\x12\x34\n\x06output\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x06output\"\xa7\x02\n\x12\x45ventSpecification\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0b\x64\x65scription\x12\x41\n\rconfig_schema\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0c\x63onfigSchema\x12\x43\n\x0emessage_schema\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\rmessageSchema\x12G\n\x10message_examples\x18\x05 \x03(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03R\x0fmessageExamples\"\x8b\x02\n\x1fListComponentDefinitionsRequest\x12%\n\tpage_size\x18\x01 \x01(\x05\x42\x03\xe0\x41\x01H\x00R\x08pageSize\x88\x01\x01\x12P\n\x04view\x18\x03 \x01(\x0e\x32\x32.pipeline.pipeline.v1beta.ComponentDefinition.ViewB\x03\xe0\x41\x01H\x01R\x04view\x88\x01\x01\x12 \n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01H\x02R\x06\x66ilter\x88\x01\x01\x12\x1c\n\x04page\x18\x05 \x01(\x05\x42\x03\xe0\x41\x01H\x03R\x04page\x88\x01\x01\x42\x0c\n\n_page_sizeB\x07\n\x05_viewB\t\n\x07_filterB\x07\n\x05_pageJ\x04\x08\x02\x10\x03\"\xdc\x01\n ListComponentDefinitionsResponse\x12\x62\n\x15\x63omponent_definitions\x18\x01 \x03(\x0b\x32-.pipeline.pipeline.v1beta.ComponentDefinitionR\x14\x63omponentDefinitions\x12\x1d\n\ntotal_size\x18\x03 \x01(\x05R\ttotalSize\x12\x1b\n\tpage_size\x18\x04 \x01(\x05R\x08pageSize\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04pageJ\x04\x08\x02\x10\x03\x42\x85\x02\n\x1c\x63om.pipeline.pipeline.v1betaB\x18\x43omponentDefinitionProtoP\x01ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\xa2\x02\x03PPX\xaa\x02\x18Pipeline.Pipeline.V1beta\xca\x02\x18Pipeline\\Pipeline\\V1beta\xe2\x02$Pipeline\\Pipeline\\V1beta\\GPBMetadata\xea\x02\x1aPipeline::Pipeline::V1betab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pipeline.pipeline.v1beta.component_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.pipeline.pipeline.v1betaB\030ComponentDefinitionProtoP\001ZIgithub.com/instill-ai/protogen-go/pipeline/pipeline/v1beta;pipelinev1beta\242\002\003PPX\252\002\030Pipeline.Pipeline.V1beta\312\002\030Pipeline\\Pipeline\\V1beta\342\002$Pipeline\\Pipeline\\V1beta\\GPBMetadata\352\002\032Pipeline::Pipeline::V1beta'
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY._options = None
  _COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY._serialized_options = b'8\001'
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['component_specification']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['data_specifications']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION_SPEC.fields_by_name['event_specifications']._options = None
  _COMPONENTDEFINITION_SPEC.fields_by_name['event_specifications']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['name']._options = None
  _COMPONENTDEFINITION.fields_by_name['name']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['uid']._options = None
  _COMPONENTDEFINITION.fields_by_name['uid']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['id']._options = None
  _COMPONENTDEFINITION.fields_by_name['id']._serialized_options = b'\340A\005'
  _COMPONENTDEFINITION.fields_by_name['title']._options = None
  _COMPONENTDEFINITION.fields_by_name['title']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['documentation_url']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['icon']._options = None
  _COMPONENTDEFINITION.fields_by_name['icon']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['spec']._options = None
  _COMPONENTDEFINITION.fields_by_name['spec']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['type']._options = None
  _COMPONENTDEFINITION.fields_by_name['type']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['tombstone']._options = None
  _COMPONENTDEFINITION.fields_by_name['tombstone']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['public']._options = None
  _COMPONENTDEFINITION.fields_by_name['public']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['custom']._options = None
  _COMPONENTDEFINITION.fields_by_name['custom']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['vendor']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._options = None
  _COMPONENTDEFINITION.fields_by_name['vendor_attributes']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['source_url']._options = None
  _COMPONENTDEFINITION.fields_by_name['source_url']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['version']._options = None
  _COMPONENTDEFINITION.fields_by_name['version']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['tasks']._options = None
  _COMPONENTDEFINITION.fields_by_name['tasks']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['description']._options = None
  _COMPONENTDEFINITION.fields_by_name['description']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['release_stage']._options = None
  _COMPONENTDEFINITION.fields_by_name['release_stage']._serialized_options = b'\340A\003'
  _COMPONENTDEFINITION.fields_by_name['events']._options = None
  _COMPONENTDEFINITION.fields_by_name['events']._serialized_options = b'\340A\003'
  _DATASPECIFICATION.fields_by_name['input']._options = None
  _DATASPECIFICATION.fields_by_name['input']._serialized_options = b'\340A\003'
  _DATASPECIFICATION.fields_by_name['output']._options = None
  _DATASPECIFICATION.fields_by_name['output']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['title']._options = None
  _EVENTSPECIFICATION.fields_by_name['title']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['description']._options = None
  _EVENTSPECIFICATION.fields_by_name['description']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['config_schema']._options = None
  _EVENTSPECIFICATION.fields_by_name['config_schema']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['message_schema']._options = None
  _EVENTSPECIFICATION.fields_by_name['message_schema']._serialized_options = b'\340A\003'
  _EVENTSPECIFICATION.fields_by_name['message_examples']._options = None
  _EVENTSPECIFICATION.fields_by_name['message_examples']._serialized_options = b'\340A\003'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['view']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._options = None
  _LISTCOMPONENTDEFINITIONSREQUEST.fields_by_name['page']._serialized_options = b'\340A\001'
  _globals['_COMPONENTDEFINITION']._serialized_start=184
  _globals['_COMPONENTDEFINITION']._serialized_end=1910
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_start=1066
  _globals['_COMPONENTDEFINITION_SPEC']._serialized_end=1658
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_start=1426
  _globals['_COMPONENTDEFINITION_SPEC_DATASPECIFICATIONSENTRY']._serialized_end=1540
  _globals['_COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY']._serialized_start=1542
  _globals['_COMPONENTDEFINITION_SPEC_EVENTSPECIFICATIONSENTRY']._serialized_end=1658
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_start=1660
  _globals['_COMPONENTDEFINITION_VIEW']._serialized_end=1719
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_start=1722
  _globals['_COMPONENTDEFINITION_RELEASESTAGE']._serialized_end=1910
  _globals['_DATASPECIFICATION']._serialized_start=1912
  _globals['_DATASPECIFICATION']._serialized_end=2037
  _globals['_EVENTSPECIFICATION']._serialized_start=2040
  _globals['_EVENTSPECIFICATION']._serialized_end=2335
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_start=2338
  _globals['_LISTCOMPONENTDEFINITIONSREQUEST']._serialized_end=2605
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_start=2608
  _globals['_LISTCOMPONENTDEFINITIONSRESPONSE']._serialized_end=2828
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/agent_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from agent.agent.v1alpha import agent_pb2 as agent_dot_agent_dot_v1alpha_dot_agent__pb2
from agent.agent.v1alpha import chat_pb2 as agent_dot_agent_dot_v1alpha_dot_chat__pb2
from agent.agent.v1alpha import table_pb2 as agent_dot_agent_dot_v1alpha_dot_table__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.agent/agent/v1alpha/agent_public_service.proto\x12\x13\x61gent.agent.v1alpha\x1a\x1f\x61gent/agent/v1alpha/agent.proto\x1a\x1e\x61gent/agent/v1alpha/chat.proto\x1a\x1f\x61gent/agent/v1alpha/table.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xee?\n\x12\x41gentPublicService\x12\x9d\x01\n\x08Liveness\x12$.agent.agent.v1alpha.LivenessRequest\x1a%.agent.agent.v1alpha.LivenessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x13/v1alpha/__livenessZ\x17\x12\x15/v1alpha/health/agent\x12\xa0\x01\n\tReadiness\x12%.agent.agent.v1alpha.ReadinessRequest\x1a&.agent.agent.v1alpha.ReadinessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x14/v1alpha/__readinessZ\x16\x12\x14/v1alpha/ready/agent\x12\xb5\x01\n\nCreateChat\x12&.agent.agent.v1alpha.CreateChatRequest\x1a\'.agent.agent.v1alpha.CreateChatResponse\"V\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02-\"(/v1alpha/namespaces/{namespace_id}/chats:\x01*\x12\xaf\x01\n\tListChats\x12%.agent.agent.v1alpha.ListChatsRequest\x1a&.agent.agent.v1alpha.ListChatsResponse\"S\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02*\x12(/v1alpha/namespaces/{namespace_id}/chats\x12\xc0\x01\n\nUpdateChat\x12&.agent.agent.v1alpha.UpdateChatRequest\x1a\'.agent.agent.v1alpha.UpdateChatResponse\"a\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x38\x1a\x33/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}:\x01*\x12\xb4\x01\n\x07GetChat\x12#.agent.agent.v1alpha.GetChatRequest\x1a$.agent.agent.v1alpha.GetChatResponse\"^\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x35\x12\x33/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}\x12\xbd\x01\n\nDeleteChat\x12&.agent.agent.v1alpha.DeleteChatRequest\x1a\'.agent.agent.v1alpha.DeleteChatResponse\"^\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x35*3/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}\x12\xcc\x01\n\x0cListMessages\x12(.agent.agent.v1alpha.ListMessagesRequest\x1a).agent.agent.v1alpha.ListMessagesResponse\"g\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>\x12</v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/messages\x12\xdb\x01\n\rChatWithAgent\x12).agent.agent.v1alpha.ChatWithAgentRequest\x1a*.agent.agent.v1alpha.ChatWithAgentResponse\"q\x92\x41 \n\n\xf0\x9f\x8d\x8e Agentj\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02H\"C/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/chat-with-agent:\x01*0\x01\x12\xcf\x01\n\rBindChatTable\x12).agent.agent.v1alpha.BindChatTableRequest\x1a*.agent.agent.v1alpha.BindChatTableResponse\"g\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x43\">/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/bind-table:\x01*\x12\xd7\x01\n\x0fUnbindChatTable\x12+.agent.agent.v1alpha.UnbindChatTableRequest\x1a,.agent.agent.v1alpha.UnbindChatTableResponse\"i\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x45\"@/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/unbind-table:\x01*\x12\xcb\x01\n\x0eListChatTables\x12*.agent.agent.v1alpha.ListChatTablesRequest\x1a+.agent.agent.v1alpha.ListChatTablesResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/tables\x12\xae\x01\n\nListTables\x12&.agent.agent.v1alpha.ListTablesRequest\x1a\'.agent.agent.v1alpha.ListTablesResponse\"O\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02+\x12)/v1alpha/namespaces/{namespace_id}/tables\x12\xb8\x01\n\x0b\x43reateTable\x12\'.agent.agent.v1alpha.CreateTableRequest\x1a(.agent.agent.v1alpha.CreateTableResponse\"V\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x32\")/v1alpha/namespaces/{namespace_id}/tables:\x05table\x12\xb4\x01\n\x08GetTable\x12$.agent.agent.v1alpha.GetTableRequest\x1a%.agent.agent.v1alpha.GetTableResponse\"[\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x37\x12\x35/v1alpha/namespaces/{namespace_id}/tables/{table_uid}\x12\xc4\x01\n\x0bUpdateTable\x12\'.agent.agent.v1alpha.UpdateTableRequest\x1a(.agent.agent.v1alpha.UpdateTableResponse\"b\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>25/v1alpha/namespaces/{namespace_id}/tables/{table_uid}:\x05table\x12\xbd\x01\n\x0b\x44\x65leteTable\x12\'.agent.agent.v1alpha.DeleteTableRequest\x1a(.agent.agent.v1alpha.DeleteTableResponse\"[\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x37*5/v1alpha/namespaces/{namespace_id}/tables/{table_uid}\x12\x84\x02\n\x19\x43hatWithTableBuilderAgent\x12\x35.agent.agent.v1alpha.ChatWithTableBuilderAgentRequest\x1a\x36.agent.agent.v1alpha.ChatWithTableBuilderAgentResponse\"v\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02R\"M/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/chat-with-agent:\x01*0\x01\x12\x84\x02\n\x1dListTableBuilderAgentMessages\x12\x39.agent.agent.v1alpha.ListTableBuilderAgentMessagesRequest\x1a:.agent.agent.v1alpha.ListTableBuilderAgentMessagesResponse\"l\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02H\x12\x46/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/messages\x12\xeb\x01\n\x14GetColumnDefinitions\x12\x30.agent.agent.v1alpha.GetColumnDefinitionsRequest\x1a\x31.agent.agent.v1alpha.GetColumnDefinitionsResponse\"n\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02J\x12H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions\x12\x89\x02\n\x17UpdateColumnDefinitions\x12\x33.agent.agent.v1alpha.UpdateColumnDefinitionsRequest\x1a\x34.agent.agent.v1alpha.UpdateColumnDefinitionsResponse\"\x82\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02^\x1aH/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions:\x12\x63olumn_definitions\x12\xf5\x01\n\x13GetColumnDefinition\x12/.agent.agent.v1alpha.GetColumnDefinitionRequest\x1a\x30.agent.agent.v1alpha.GetColumnDefinitionResponse\"{\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}\x12\xf4\x01\n\x0fRecomputeColumn\x12+.agent.agent.v1alpha.RecomputeColumnRequest\x1a,.agent.agent.v1alpha.RecomputeColumnResponse\"\x85\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x61\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}/recompute\x12\xb9\x01\n\x08ListRows\x12$.agent.agent.v1alpha.ListRowsRequest\x1a%.agent.agent.v1alpha.ListRowsResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows\x12\xbd\x01\n\x06GetRow\x12\".agent.agent.v1alpha.GetRowRequest\x1a#.agent.agent.v1alpha.GetRowResponse\"j\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x46\x12\x44/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}\x12\xbf\x01\n\tInsertRow\x12%.agent.agent.v1alpha.InsertRowRequest\x1a&.agent.agent.v1alpha.InsertRowResponse\"c\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02?\":/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\x01*\x12\xc9\x01\n\tUpdateRow\x12%.agent.agent.v1alpha.UpdateRowRequest\x1a&.agent.agent.v1alpha.UpdateRowResponse\"m\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02I2D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}:\x01*\x12\xc2\x01\n\nUpdateRows\x12&.agent.agent.v1alpha.UpdateRowsRequest\x1a\'.agent.agent.v1alpha.UpdateRowsResponse\"c\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02?2:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\x01*\x12\xc6\x01\n\tDeleteRow\x12%.agent.agent.v1alpha.DeleteRowRequest\x1a&.agent.agent.v1alpha.DeleteRowResponse\"j\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x46*D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}\x12\xbf\x01\n\nDeleteRows\x12&.agent.agent.v1alpha.DeleteRowsRequest\x1a\'.agent.agent.v1alpha.DeleteRowsResponse\"`\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02<*:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows\x12\xc1\x01\n\x08MoveRows\x12$.agent.agent.v1alpha.MoveRowsRequest\x1a%.agent.agent.v1alpha.MoveRowsResponse\"h\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x44\"?/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/move-rows:\x01*\x12\xd1\x01\n\x07GetCell\x12#.agent.agent.v1alpha.GetCellRequest\x1a$.agent.agent.v1alpha.GetCellResponse\"{\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}\x12\xdd\x01\n\nUpdateCell\x12&.agent.agent.v1alpha.UpdateCellRequest\x1a\'.agent.agent.v1alpha.UpdateCellResponse\"~\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02Z2U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}:\x01*\x12\xe1\x01\n\tResetCell\x12%.agent.agent.v1alpha.ResetCellRequest\x1a&.agent.agent.v1alpha.ResetCellResponse\"\x84\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02`\"[/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/reset:\x01*\x12\xf1\x01\n\rRecomputeCell\x12).agent.agent.v1alpha.RecomputeCellRequest\x1a*.agent.agent.v1alpha.RecomputeCellResponse\"\x88\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x64\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/recompute:\x01*\x12\xdd\x01\n\x08LockCell\x12$.agent.agent.v1alpha.LockCellRequest\x1a%.agent.agent.v1alpha.LockCellResponse\"\x83\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02_\"Z/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/lock:\x01*\x12\xe5\x01\n\nUnlockCell\x12&.agent.agent.v1alpha.UnlockCellRequest\x1a\'.agent.agent.v1alpha.UnlockCellResponse\"\x85\x01\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x61\"\\/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/unlock:\x01*\x12\xcf\x01\n\x0eGetTableEvents\x12*.agent.agent.v1alpha.GetTableEventsRequest\x1a+.agent.agent.v1alpha.GetTableEventsResponse\"b\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02>\x12</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/events0\x01\x12\xc7\x01\n\x0b\x45xportTable\x12\'.agent.agent.v1alpha.ExportTableRequest\x1a(.agent.agent.v1alpha.ExportTableResponse\"e\x92\x41\x1b\n\x05Tablej\x12\n\x07x-stage\x12\x07\x1a\x05\x61lpha\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/export:\x01*\x1a\x1b\x92\x41\x18\x12\x16Public Agent endpointsB\xe4\x01\n\x17\x63om.agent.agent.v1alphaB\x17\x41gentPublicServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.agent_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\027AgentPublicServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _AGENTPUBLICSERVICE._options = None
  _AGENTPUBLICSERVICE._serialized_options = b'\222A\030\022\026Public Agent endpoints'
  _AGENTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\023/v1alpha/__livenessZ\027\022\025/v1alpha/health/agent'
  _AGENTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\024/v1alpha/__readinessZ\026\022\024/v1alpha/ready/agent'
  _AGENTPUBLICSERVICE.methods_by_name['CreateChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['CreateChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002-\"(/v1alpha/namespaces/{namespace_id}/chats:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListChats']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListChats']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002*\022(/v1alpha/namespaces/{namespace_id}/chats'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0028\0323/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0025\0223/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteChat']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteChat']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0025*3/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['ListMessages']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListMessages']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>\022</v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/messages'
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithAgent']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithAgent']._serialized_options = b'\222A \n\n\360\237\215\216 Agentj\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002H\"C/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/chat-with-agent:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['BindChatTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['BindChatTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002C\">/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/bind-table:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UnbindChatTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UnbindChatTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002E\"@/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/unbind-table:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListChatTables']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListChatTables']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/chats/{chat_uid}/tables'
  _AGENTPUBLICSERVICE.methods_by_name['ListTables']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListTables']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002+\022)/v1alpha/namespaces/{namespace_id}/tables'
  _AGENTPUBLICSERVICE.methods_by_name['CreateTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['CreateTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0022\")/v1alpha/namespaces/{namespace_id}/tables:\005table'
  _AGENTPUBLICSERVICE.methods_by_name['GetTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0027\0225/v1alpha/namespaces/{namespace_id}/tables/{table_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>25/v1alpha/namespaces/{namespace_id}/tables/{table_uid}:\005table'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\0027*5/v1alpha/namespaces/{namespace_id}/tables/{table_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithTableBuilderAgent']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ChatWithTableBuilderAgent']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002R\"M/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/chat-with-agent:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ListTableBuilderAgentMessages']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListTableBuilderAgentMessages']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002H\022F/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/builder/messages'
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinitions']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinitions']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002J\022H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateColumnDefinitions']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateColumnDefinitions']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002^\032H/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions:\022column_definitions'
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinition']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetColumnDefinition']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeColumn']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeColumn']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002a\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/column-definitions/{column_uid}/recompute'
  _AGENTPUBLICSERVICE.methods_by_name['ListRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ListRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows'
  _AGENTPUBLICSERVICE.methods_by_name['GetRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002F\022D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['InsertRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['InsertRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002?\":/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002I2D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002?2:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRow']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRow']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002F*D/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['DeleteRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002<*:/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows'
  _AGENTPUBLICSERVICE.methods_by_name['MoveRows']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['MoveRows']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002D\"?/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/move-rows:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}'
  _AGENTPUBLICSERVICE.methods_by_name['UpdateCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UpdateCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002Z2U/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['ResetCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ResetCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002`\"[/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/reset:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['RecomputeCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002d\"_/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/recompute:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['LockCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['LockCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002_\"Z/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/lock:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['UnlockCell']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['UnlockCell']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002a\"\\/v1alpha/namespaces/{namespace_id}/tables/{table_uid}/rows/{row_uid}/cells/{cell_uid}/unlock:\001*'
  _AGENTPUBLICSERVICE.methods_by_name['GetTableEvents']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['GetTableEvents']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002>\022</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/events'
  _AGENTPUBLICSERVICE.methods_by_name['ExportTable']._options = None
  _AGENTPUBLICSERVICE.methods_by_name['ExportTable']._serialized_options = b'\222A\033\n\005Tablej\022\n\007x-stage\022\007\032\005alpha\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/tables/{table_uid}/export:\001*'
  _globals['_AGENTPUBLICSERVICE']._serialized_start=277
  _globals['_AGENTPUBLICSERVICE']._serialized_end=8451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent/agent/v1alpha/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common.healthcheck.v1beta import healthcheck_pb2 as common_dot_healthcheck_dot_v1beta_dot_healthcheck__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61gent/agent/v1alpha/agent.proto\x12\x13\x61gent.agent.v1alpha\x1a+common/healthcheck/v1beta/healthcheck.proto\x1a\x1fgoogle/api/field_behavior.proto\"\x95\x01\n\x0fLivenessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"{\n\x10LivenessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponse\"\x96\x01\n\x10ReadinessRequest\x12i\n\x14health_check_request\x18\x01 \x01(\x0b\x32-.common.healthcheck.v1beta.HealthCheckRequestB\x03\xe0\x41\x01H\x00R\x12healthCheckRequest\x88\x01\x01\x42\x17\n\x15_health_check_request\"|\n\x11ReadinessResponse\x12g\n\x15health_check_response\x18\x01 \x01(\x0b\x32..common.healthcheck.v1beta.HealthCheckResponseB\x03\xe0\x41\x03R\x13healthCheckResponseB\xd7\x01\n\x17\x63om.agent.agent.v1alphaB\nAgentProtoP\x01ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x13\x41gent.Agent.V1alpha\xca\x02\x13\x41gent\\Agent\\V1alpha\xe2\x02\x1f\x41gent\\Agent\\V1alpha\\GPBMetadata\xea\x02\x15\x41gent::Agent::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent.agent.v1alpha.agent_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.agent.agent.v1alphaB\nAgentProtoP\001ZBgithub.com/instill-ai/protogen-go/agent/agent/v1alpha;agentv1alpha\242\002\003AAX\252\002\023Agent.Agent.V1alpha\312\002\023Agent\\Agent\\V1alpha\342\002\037Agent\\Agent\\V1alpha\\GPBMetadata\352\002\025Agent::Agent::V1alpha'
  _LIVENESSREQUEST.fields_by_name['health_check_request']._options = None
  _LIVENESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._options = None
  _LIVENESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _READINESSREQUEST.fields_by_name['health_check_request']._options = None
  _READINESSREQUEST.fields_by_name['health_check_request']._serialized_options = b'\340A\001'
  _READINESSRESPONSE.fields_by_name['health_check_response']._options = None
  _READINESSRESPONSE.fields_by_name['health_check_response']._serialized_options = b'\340A\003'
  _globals['_LIVENESSREQUEST']._serialized_start=135
  _globals['_LIVENESSREQUEST']._serialized_end=284
  _globals['_LIVENESSRESPONSE']._serialized_start=286
  _globals['_LIVENESSRESPONSE']._serialized_end=409
  _globals['_READINESSREQUEST']._serialized_start=412
  _globals['_READINESSREQUEST']._serialized_end=562
  _globals['_READINESSRESPONSE']._serialized_start=564
  _globals['_READINESSRESPONSE']._serialized_end=688
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/ray/v1alpha/user_defined.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$model/ray/v1alpha/user_defined.proto\x12\x11model.ray.v1alpha\x1a\x1cgoogle/protobuf/struct.proto\"G\n\x0b\x43\x61llRequest\x12\x38\n\x0btask_inputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\ntaskInputs\"J\n\x0c\x43\x61llResponse\x12:\n\x0ctask_outputs\x18\x01 \x03(\x0b\x32\x17.google.protobuf.StructR\x0btaskOutputs2a\n\x12UserDefinedService\x12K\n\x08__call__\x12\x1e.model.ray.v1alpha.CallRequest\x1a\x1f.model.ray.v1alpha.CallResponseB\xcf\x01\n\x15\x63om.model.ray.v1alphaB\x10UserDefinedProtoP\x01Z>github.com/instill-ai/protogen-go/model/ray/v1alpha;rayv1alpha\xa2\x02\x03MRX\xaa\x02\x11Model.Ray.V1alpha\xca\x02\x11Model\\Ray\\V1alpha\xe2\x02\x1dModel\\Ray\\V1alpha\\GPBMetadata\xea\x02\x13Model::Ray::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.ray.v1alpha.user_defined_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.model.ray.v1alphaB\020UserDefinedProtoP\001Z>github.com/instill-ai/protogen-go/model/ray/v1alpha;rayv1alpha\242\002\003MRX\252\002\021Model.Ray.V1alpha\312\002\021Model\\Ray\\V1alpha\342\002\035Model\\Ray\\V1alpha\\GPBMetadata\352\002\023Model::Ray::V1alpha'
  _globals['_CALLREQUEST']._serialized_start=89
  _globals['_CALLREQUEST']._serialized_end=160
  _globals['_CALLRESPONSE']._serialized_start=162
  _globals['_CALLRESPONSE']._serialized_end=236
  _globals['_USERDEFINEDSERVICE']._serialized_start=238
  _globals['_USERDEFINEDSERVICE']._serialized_end=335
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import agent.agent.v1alpha.common_pb2
import agent.agent.v1alpha.table_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AgentConfig(google.protobuf.message.Message):
    """AgentConfig represents the config for the chat agent."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConnectionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    INSTRUCTIONS_FIELD_NUMBER: builtins.int
    CONNECTIONS_FIELD_NUMBER: builtins.int
    instructions: builtins.str
    """instructions"""
    @property
    def connections(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """connection key(used connection id in recipe) and value(connection uid from namespace)."""
    def __init__(
        self,
        *,
        instructions: builtins.str = ...,
        connections: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connections", b"connections", "instructions", b"instructions"]) -> None: ...

global___AgentConfig = AgentConfig

@typing_extensions.final
class Chat(google.protobuf.message.Message):
    """Chat represents a chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_DISPLAY_NAME_FIELD_NUMBER: builtins.int
    AGENT_CONFIG_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """unique identifier of the conversation created by the system."""
    namespace_id: builtins.str
    """namespace id."""
    chat_display_name: builtins.str
    """conversation display name."""
    @property
    def agent_config(self) -> global___AgentConfig:
        """agent config."""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """chat create time."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """chat update time."""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """chat delete time."""
    catalog_id: builtins.str
    """catalog id"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        namespace_id: builtins.str = ...,
        chat_display_name: builtins.str = ...,
        agent_config: global___AgentConfig | None = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config", "create_time", b"create_time", "delete_time", b"delete_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config", "catalog_id", b"catalog_id", "chat_display_name", b"chat_display_name", "create_time", b"create_time", "delete_time", b"delete_time", "namespace_id", b"namespace_id", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___Chat = Chat

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """Message represents a single message in a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MessageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Message._MessageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MESSAGE_TYPE_UNSPECIFIED: Message._MessageType.ValueType  # 0
        """unspecified"""
        MESSAGE_TYPE_TEXT: Message._MessageType.ValueType  # 1
        """text"""

    class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
        """message type"""

    MESSAGE_TYPE_UNSPECIFIED: Message.MessageType.ValueType  # 0
    """unspecified"""
    MESSAGE_TYPE_TEXT: Message.MessageType.ValueType  # 1
    """text"""

    UID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    MSG_SENDER_UID_FIELD_NUMBER: builtins.int
    CITATIONS_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    ATTACHMENTS_FIELD_NUMBER: builtins.int
    ENABLE_WEB_SEARCH_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """message uid"""
    chat_uid: builtins.str
    """chat uid"""
    content: builtins.str
    """message content"""
    role: builtins.str
    """message role e.g., "user" or "assistant" or "agent" """
    type: global___Message.MessageType.ValueType
    """message type"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """creation time of the message"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time of the message"""
    msg_sender_uid: builtins.str
    """message sender uid(only for user messages)"""
    @property
    def citations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[agent.agent.v1alpha.common_pb2.Citation]:
        """citations (only for agent messages)"""
    @property
    def context(self) -> global___ChatContext:
        """context for the message"""
    @property
    def attachments(self) -> global___ChatAttachments:
        """attachments for the message"""
    enable_web_search: builtins.bool
    """enable web search (only for user messages)"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        chat_uid: builtins.str = ...,
        content: builtins.str = ...,
        role: builtins.str = ...,
        type: global___Message.MessageType.ValueType = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        msg_sender_uid: builtins.str = ...,
        citations: collections.abc.Iterable[agent.agent.v1alpha.common_pb2.Citation] | None = ...,
        context: global___ChatContext | None = ...,
        attachments: global___ChatAttachments | None = ...,
        enable_web_search: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachments", b"attachments", "context", b"context", "create_time", b"create_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachments", b"attachments", "chat_uid", b"chat_uid", "citations", b"citations", "content", b"content", "context", b"context", "create_time", b"create_time", "enable_web_search", b"enable_web_search", "msg_sender_uid", b"msg_sender_uid", "role", b"role", "type", b"type", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___Message = Message

@typing_extensions.final
class ChatContext(google.protobuf.message.Message):
    """The context for the message."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_UIDS_FIELD_NUMBER: builtins.int
    @property
    def table_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The table uids to include in the context."""
    def __init__(
        self,
        *,
        table_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["table_uids", b"table_uids"]) -> None: ...

global___ChatContext = ChatContext

@typing_extensions.final
class ChatAttachments(google.protobuf.message.Message):
    """ChatAttachments represents the attachment for the message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_URLS_FIELD_NUMBER: builtins.int
    @property
    def file_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """file urls (only for user messages)"""
    def __init__(
        self,
        *,
        file_urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_urls", b"file_urls"]) -> None: ...

global___ChatAttachments = ChatAttachments

@typing_extensions.final
class CreateChatRequest(google.protobuf.message.Message):
    """CreateChatRequest is used to create a new chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_DISPLAY_NAME_FIELD_NUMBER: builtins.int
    AGENT_CONFIG_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_display_name: builtins.str
    """chat display name"""
    @property
    def agent_config(self) -> global___AgentConfig:
        """agent config"""
    catalog_id: builtins.str
    """catalog id"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_display_name: builtins.str = ...,
        agent_config: global___AgentConfig | None = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config", "catalog_id", b"catalog_id", "chat_display_name", b"chat_display_name", "namespace_id", b"namespace_id"]) -> None: ...

global___CreateChatRequest = CreateChatRequest

@typing_extensions.final
class CreateChatResponse(google.protobuf.message.Message):
    """CreateChatResponse returns the created chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_FIELD_NUMBER: builtins.int
    @property
    def chat(self) -> global___Chat:
        """chat"""
    def __init__(
        self,
        *,
        chat: global___Chat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> None: ...

global___CreateChatResponse = CreateChatResponse

@typing_extensions.final
class ListChatsRequest(google.protobuf.message.Message):
    """ListChatsRequest is used to list chats"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    IF_ALL_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    page_size: builtins.int
    """page size"""
    page_token: builtins.str
    """page token"""
    if_all: builtins.bool
    """if true, all chats will be returned. This has higher priority over page_size and page_token."""
    chat_uid: builtins.str
    """chat_uid this is optional, if provided, only the chat with the given chat_uid will be returned
    first check chat_uid then check if_all
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        if_all: builtins.bool = ...,
        chat_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_uid", b"chat_uid", "if_all", b"if_all", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListChatsRequest = ListChatsRequest

@typing_extensions.final
class ListChatsResponse(google.protobuf.message.Message):
    """ListChatsResponse returns a list of chats"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHATS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def chats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chat]:
        """chats"""
    next_page_token: builtins.str
    """next page token"""
    total_size: builtins.int
    """total size"""
    def __init__(
        self,
        *,
        chats: collections.abc.Iterable[global___Chat] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chats", b"chats", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListChatsResponse = ListChatsResponse

@typing_extensions.final
class UpdateChatRequest(google.protobuf.message.Message):
    """UpdateChatRequest is used to update a chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    CHAT_DISPLAY_NAME_FIELD_NUMBER: builtins.int
    AGENT_CONFIG_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_uid: builtins.str
    """chat uid"""
    chat_display_name: builtins.str
    """chat display name"""
    @property
    def agent_config(self) -> global___AgentConfig:
        """ai agent settings"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_uid: builtins.str = ...,
        chat_display_name: builtins.str = ...,
        agent_config: global___AgentConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["agent_config", b"agent_config", "chat_display_name", b"chat_display_name", "chat_uid", b"chat_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___UpdateChatRequest = UpdateChatRequest

@typing_extensions.final
class UpdateChatResponse(google.protobuf.message.Message):
    """UpdateChatResponse returns the updated chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_FIELD_NUMBER: builtins.int
    @property
    def chat(self) -> global___Chat:
        """chat"""
    def __init__(
        self,
        *,
        chat: global___Chat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> None: ...

global___UpdateChatResponse = UpdateChatResponse

@typing_extensions.final
class GetChatRequest(google.protobuf.message.Message):
    """GetChatRequest is used to get a chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_uid: builtins.str
    """chat uid"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_uid", b"chat_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___GetChatRequest = GetChatRequest

@typing_extensions.final
class GetChatResponse(google.protobuf.message.Message):
    """GetChatResponse returns the chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHAT_FIELD_NUMBER: builtins.int
    @property
    def chat(self) -> global___Chat:
        """chat"""
    def __init__(
        self,
        *,
        chat: global___Chat | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat", b"chat"]) -> None: ...

global___GetChatResponse = GetChatResponse

@typing_extensions.final
class DeleteChatRequest(google.protobuf.message.Message):
    """DeleteChatRequest is used to delete a chat"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_uid: builtins.str
    """chat uid"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_uid", b"chat_uid", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteChatRequest = DeleteChatRequest

@typing_extensions.final
class DeleteChatResponse(google.protobuf.message.Message):
    """DeleteChatResponse is empty as no content needs to be returned"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteChatResponse = DeleteChatResponse

@typing_extensions.final
class MessageSenderProfile(google.protobuf.message.Message):
    """MessageSenderProfile describes the public data of a message sender.
    refer to core.mgmt.v1beta.UserProfile for more details.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_SENDER_UID_FIELD_NUMBER: builtins.int
    MSG_SENDER_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    msg_sender_uid: builtins.str
    """sender uid"""
    msg_sender_id: builtins.str
    """sender id"""
    display_name: builtins.str
    """Display name."""
    avatar: builtins.str
    """Avatar url. this url might be expired or not exist."""
    def __init__(
        self,
        *,
        msg_sender_uid: builtins.str = ...,
        msg_sender_id: builtins.str = ...,
        display_name: builtins.str | None = ...,
        avatar: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_avatar", b"_avatar", "_display_name", b"_display_name", "avatar", b"avatar", "display_name", b"display_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_avatar", b"_avatar", "_display_name", b"_display_name", "avatar", b"avatar", "display_name", b"display_name", "msg_sender_id", b"msg_sender_id", "msg_sender_uid", b"msg_sender_uid"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_avatar", b"_avatar"]) -> typing_extensions.Literal["avatar"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_display_name", b"_display_name"]) -> typing_extensions.Literal["display_name"] | None: ...

global___MessageSenderProfile = MessageSenderProfile

@typing_extensions.final
class ListMessagesRequest(google.protobuf.message.Message):
    """ListMessagesRequest is used to list messages in a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    IF_ALL_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_uid: builtins.str
    """chat uid"""
    page_size: builtins.int
    """page size"""
    page_token: builtins.str
    """page token"""
    if_all: builtins.bool
    """If true, all messages will be returned. This has higher priority over page_size and page_token."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_uid: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        if_all: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_uid", b"chat_uid", "if_all", b"if_all", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMessagesRequest = ListMessagesRequest

@typing_extensions.final
class ListMessagesResponse(google.protobuf.message.Message):
    """ListMessagesResponse returns a list of messages"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    SENDER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Message]:
        """messages"""
    next_page_token: builtins.str
    """next page token"""
    total_size: builtins.int
    """total size"""
    @property
    def sender_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageSenderProfile]:
        """message sender profiles"""
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[global___Message] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
        sender_profiles: collections.abc.Iterable[global___MessageSenderProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "next_page_token", b"next_page_token", "sender_profiles", b"sender_profiles", "total_size", b"total_size"]) -> None: ...

global___ListMessagesResponse = ListMessagesResponse

@typing_extensions.final
class ChatWithAgentRequest(google.protobuf.message.Message):
    """ChatWithAgentRequest represents a request to send a message
    to a chatbot synchronously and streams back the results.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CHAT_UID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    FILE_UIDS_FIELD_NUMBER: builtins.int
    ENABLE_WEB_SEARCH_FIELD_NUMBER: builtins.int
    OBJECT_UIDS_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    chat_uid: builtins.str
    """chat uid"""
    message: builtins.str
    """User message"""
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """file UIDs"""
    enable_web_search: builtins.bool
    """Whether to enable web search for the chat."""
    @property
    def object_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """object UIDs"""
    @property
    def context(self) -> global___ChatContext:
        """The context for the chat."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        chat_uid: builtins.str = ...,
        message: builtins.str = ...,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
        enable_web_search: builtins.bool = ...,
        object_uids: collections.abc.Iterable[builtins.str] | None = ...,
        context: global___ChatContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_uid", b"chat_uid", "context", b"context", "enable_web_search", b"enable_web_search", "file_uids", b"file_uids", "message", b"message", "namespace_id", b"namespace_id", "object_uids", b"object_uids"]) -> None: ...

global___ChatWithAgentRequest = ChatWithAgentRequest

@typing_extensions.final
class ChatWithAgentResponse(google.protobuf.message.Message):
    """ChatWithAgentResponse contains the chatbot response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.struct_pb2.Struct]:
        """Conversation responses."""
    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[google.protobuf.struct_pb2.Struct] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> None: ...

global___ChatWithAgentResponse = ChatWithAgentResponse

@typing_extensions.final
class TableBuilderAgentMessage(google.protobuf.message.Message):
    """TableBuilderAgentMessage represents a message from the table builder agent."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """The message."""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message"]) -> None: ...

global___TableBuilderAgentMessage = TableBuilderAgentMessage

@typing_extensions.final
class ListTableBuilderAgentMessagesRequest(google.protobuf.message.Message):
    """ListTableBuilderAgentMessagesRequest is used to list messages in a conversation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    TABLE_UID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    IF_ALL_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """namespace id"""
    table_uid: builtins.str
    """table uid"""
    page_size: builtins.int
    """page size"""
    page_token: builtins.str
    """page token"""
    if_all: builtins.bool
    """If true, all messages will be returned. This has higher priority over page_size and page_token."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        table_uid: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        if_all: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["if_all", b"if_all", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token", "table_uid", b"table_uid"]) -> None: ...

global___ListTableBuilderAgentMessagesRequest = ListTableBuilderAgentMessagesRequest

@typing_extensions.final
class ListTableBuilderAgentMessagesResponse(google.protobuf.message.Message):
    """ListTableBuilderAgentMessagesResponse returns a list of messages"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    SENDER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Message]:
        """messages"""
    next_page_token: builtins.str
    """next page token"""
    total_size: builtins.int
    """total size"""
    @property
    def sender_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageSenderProfile]:
        """message sender profiles"""
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[global___Message] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
        sender_profiles: collections.abc.Iterable[global___MessageSenderProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages", b"messages", "next_page_token", b"next_page_token", "sender_profiles", b"sender_profiles", "total_size", b"total_size"]) -> None: ...

global___ListTableBuilderAgentMessagesResponse = ListTableBuilderAgentMessagesResponse

@typing_extensions.final
class ChatWithTableBuilderAgentRequest(google.protobuf.message.Message):
    """ChatWithTableBuilderAgentRequest represents a request to chat with the table builder agent."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    TABLE_UID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the namespace that owns the table."""
    table_uid: builtins.str
    """The UID of the table to send a message to."""
    message: builtins.str
    """User message"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        table_uid: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "namespace_id", b"namespace_id", "table_uid", b"table_uid"]) -> None: ...

global___ChatWithTableBuilderAgentRequest = ChatWithTableBuilderAgentRequest

@typing_extensions.final
class ChatWithTableBuilderAgentResponse(google.protobuf.message.Message):
    """ChatWithTableBuilderAgentResponse contains the response from the table builder agent."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    @property
    def event(self) -> global___ChatEvent:
        """The response from the table builder agent."""
    def __init__(
        self,
        *,
        event: global___ChatEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["event", b"event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["event", b"event"]) -> None: ...

global___ChatWithTableBuilderAgentResponse = ChatWithTableBuilderAgentResponse

@typing_extensions.final
class ChatEvent(google.protobuf.message.Message):
    """ChatEvent represents an event for a chat."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CHAT_STARTED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_STATUS_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_OUTPUT_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_NAME_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_REPLAN_TRIGGERED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_CITATION_LIST_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_TABLE_CREATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_ERROR_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_DEBUG_OUTPUT_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_ENDED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_ATTACHMENTS_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_CONTEXT_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    CHAT_TABLE_UPDATED_EVENT_FIELD_NUMBER: builtins.int
    event: builtins.str
    """The event type.
    In text/event-stream format, this maps to the `event` field.
    """
    id: builtins.str
    """The ID of the event.
    In text/event-stream format, this maps to the `id` field.
    """
    @property
    def chat_started_event(self) -> global___ChatStartedEvent:
        """The chat was started."""
    @property
    def chat_status_updated_event(self) -> global___ChatStatusUpdatedEvent:
        """The chat status was updated."""
    @property
    def chat_output_updated_event(self) -> global___ChatOutputUpdatedEvent:
        """The chat output was updated."""
    @property
    def chat_name_updated_event(self) -> global___ChatNameUpdatedEvent:
        """The chat name was updated."""
    @property
    def chat_replan_triggered_event(self) -> global___ChatReplanTriggeredEvent:
        """The chat replan was triggered."""
    @property
    def chat_citation_list_updated_event(self) -> global___ChatCitationListUpdatedEvent:
        """The chat citation list was updated."""
    @property
    def chat_table_created_event(self) -> global___ChatTableCreatedEvent:
        """The table was created."""
    @property
    def chat_error_updated_event(self) -> global___ChatErrorUpdatedEvent:
        """The error was updated."""
    @property
    def chat_debug_output_updated_event(self) -> global___ChatDebugOutputUpdatedEvent:
        """The debug output was updated."""
    @property
    def chat_ended_event(self) -> global___ChatEndedEvent:
        """The chat ended."""
    @property
    def chat_attachments_updated_event(self) -> global___ChatAttachmentsUpdatedEvent:
        """The chat attachments were updated."""
    @property
    def chat_context_updated_event(self) -> global___ChatContextUpdatedEvent:
        """The chat context was updated."""
    @property
    def chat_table_updated_event(self) -> global___ChatTableUpdatedEvent:
        """The table was updated."""
    def __init__(
        self,
        *,
        event: builtins.str = ...,
        id: builtins.str = ...,
        chat_started_event: global___ChatStartedEvent | None = ...,
        chat_status_updated_event: global___ChatStatusUpdatedEvent | None = ...,
        chat_output_updated_event: global___ChatOutputUpdatedEvent | None = ...,
        chat_name_updated_event: global___ChatNameUpdatedEvent | None = ...,
        chat_replan_triggered_event: global___ChatReplanTriggeredEvent | None = ...,
        chat_citation_list_updated_event: global___ChatCitationListUpdatedEvent | None = ...,
        chat_table_created_event: global___ChatTableCreatedEvent | None = ...,
        chat_error_updated_event: global___ChatErrorUpdatedEvent | None = ...,
        chat_debug_output_updated_event: global___ChatDebugOutputUpdatedEvent | None = ...,
        chat_ended_event: global___ChatEndedEvent | None = ...,
        chat_attachments_updated_event: global___ChatAttachmentsUpdatedEvent | None = ...,
        chat_context_updated_event: global___ChatContextUpdatedEvent | None = ...,
        chat_table_updated_event: global___ChatTableUpdatedEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["chat_attachments_updated_event", b"chat_attachments_updated_event", "chat_citation_list_updated_event", b"chat_citation_list_updated_event", "chat_context_updated_event", b"chat_context_updated_event", "chat_debug_output_updated_event", b"chat_debug_output_updated_event", "chat_ended_event", b"chat_ended_event", "chat_error_updated_event", b"chat_error_updated_event", "chat_name_updated_event", b"chat_name_updated_event", "chat_output_updated_event", b"chat_output_updated_event", "chat_replan_triggered_event", b"chat_replan_triggered_event", "chat_started_event", b"chat_started_event", "chat_status_updated_event", b"chat_status_updated_event", "chat_table_created_event", b"chat_table_created_event", "chat_table_updated_event", b"chat_table_updated_event", "data", b"data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_attachments_updated_event", b"chat_attachments_updated_event", "chat_citation_list_updated_event", b"chat_citation_list_updated_event", "chat_context_updated_event", b"chat_context_updated_event", "chat_debug_output_updated_event", b"chat_debug_output_updated_event", "chat_ended_event", b"chat_ended_event", "chat_error_updated_event", b"chat_error_updated_event", "chat_name_updated_event", b"chat_name_updated_event", "chat_output_updated_event", b"chat_output_updated_event", "chat_replan_triggered_event", b"chat_replan_triggered_event", "chat_started_event", b"chat_started_event", "chat_status_updated_event", b"chat_status_updated_event", "chat_table_created_event", b"chat_table_created_event", "chat_table_updated_event", b"chat_table_updated_event", "data", b"data", "event", b"event", "id", b"id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data", b"data"]) -> typing_extensions.Literal["chat_started_event", "chat_status_updated_event", "chat_output_updated_event", "chat_name_updated_event", "chat_replan_triggered_event", "chat_citation_list_updated_event", "chat_table_created_event", "chat_error_updated_event", "chat_debug_output_updated_event", "chat_ended_event", "chat_attachments_updated_event", "chat_context_updated_event", "chat_table_updated_event"] | None: ...

global___ChatEvent = ChatEvent

@typing_extensions.final
class ChatStartedEvent(google.protobuf.message.Message):
    """ChatStartedEvent represents an event for a chat started"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when chat start"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> None: ...

global___ChatStartedEvent = ChatStartedEvent

@typing_extensions.final
class ChatStatusUpdatedEvent(google.protobuf.message.Message):
    """ChatStatusUpdatedEvent represents an event for a chat status change"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    CHAT_STATUS_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when chat status change"""
    chat_status: builtins.str
    """The updated chat status"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        chat_status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["chat_status", b"chat_status", "create_time", b"create_time"]) -> None: ...

global___ChatStatusUpdatedEvent = ChatStatusUpdatedEvent

@typing_extensions.final
class ChatOutputUpdatedEvent(google.protobuf.message.Message):
    """ChatOutputUpdatedEvent represents an event for chat has new output"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    OUTPUT_CHUNK_DELTA_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when chat has new output"""
    output_chunk_delta: builtins.str
    """The output chunk delta"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        output_chunk_delta: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "output_chunk_delta", b"output_chunk_delta"]) -> None: ...

global___ChatOutputUpdatedEvent = ChatOutputUpdatedEvent

@typing_extensions.final
class ChatNameUpdatedEvent(google.protobuf.message.Message):
    """ChatNameUpdatedEvent represents an event for chat name change"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when chat name change"""
    name: builtins.str
    """The updated chat name"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "name", b"name"]) -> None: ...

global___ChatNameUpdatedEvent = ChatNameUpdatedEvent

@typing_extensions.final
class ChatReplanTriggeredEvent(google.protobuf.message.Message):
    """ChatReplanTriggeredEvent represents an event for a triggered replan"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    NUMBER_OF_REPLAN_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when replan trigger"""
    number_of_replan: builtins.int
    """The current number of replan"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        number_of_replan: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "number_of_replan", b"number_of_replan"]) -> None: ...

global___ChatReplanTriggeredEvent = ChatReplanTriggeredEvent

@typing_extensions.final
class ChatCitationListUpdatedEvent(google.protobuf.message.Message):
    """ChatCitationListUpdatedEvent represents an event for a citation list output"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    CITATIONS_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when citation list output"""
    @property
    def citations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[agent.agent.v1alpha.common_pb2.Citation]:
        """The citation list"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        citations: collections.abc.Iterable[agent.agent.v1alpha.common_pb2.Citation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["citations", b"citations", "create_time", b"create_time"]) -> None: ...

global___ChatCitationListUpdatedEvent = ChatCitationListUpdatedEvent

@typing_extensions.final
class ChatAttachmentsUpdatedEvent(google.protobuf.message.Message):
    """ChatAttachmentsUpdatedEvent represents an event for a attachment list output"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ATTACHMENTS_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when attachment list updated"""
    @property
    def attachments(self) -> global___ChatAttachments:
        """The attachments"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        attachments: global___ChatAttachments | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attachments", b"attachments", "create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachments", b"attachments", "create_time", b"create_time"]) -> None: ...

global___ChatAttachmentsUpdatedEvent = ChatAttachmentsUpdatedEvent

@typing_extensions.final
class ChatContextUpdatedEvent(google.protobuf.message.Message):
    """ChatContextUpdatedEvent represents an event for a context updated"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when context updated"""
    @property
    def context(self) -> global___ChatContext:
        """The context"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        context: global___ChatContext | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["context", b"context", "create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["context", b"context", "create_time", b"create_time"]) -> None: ...

global___ChatContextUpdatedEvent = ChatContextUpdatedEvent

@typing_extensions.final
class ChatTableCreatedEvent(google.protobuf.message.Message):
    """ChatTableCreatedEvent represents an event for a table creation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ColumnDefinitionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> agent.agent.v1alpha.table_pb2.ColumnDefinition: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: agent.agent.v1alpha.table_pb2.ColumnDefinition | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    TABLE_UID_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    COLUMN_DEFINITIONS_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when table is created"""
    table_uid: builtins.str
    """The created table uid"""
    @property
    def table(self) -> agent.agent.v1alpha.table_pb2.Table:
        """The created table"""
    @property
    def column_definitions(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, agent.agent.v1alpha.table_pb2.ColumnDefinition]:
        """The created column definitions"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        table_uid: builtins.str = ...,
        table: agent.agent.v1alpha.table_pb2.Table | None = ...,
        column_definitions: collections.abc.Mapping[builtins.str, agent.agent.v1alpha.table_pb2.ColumnDefinition] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_definitions", b"column_definitions", "create_time", b"create_time", "table", b"table", "table_uid", b"table_uid"]) -> None: ...

global___ChatTableCreatedEvent = ChatTableCreatedEvent

@typing_extensions.final
class ChatTableUpdatedEvent(google.protobuf.message.Message):
    """ChatTableUpdatedEvent represents an event for a table update"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ColumnDefinitionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> agent.agent.v1alpha.table_pb2.ColumnDefinition: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: agent.agent.v1alpha.table_pb2.ColumnDefinition | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    TABLE_UID_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    COLUMN_DEFINITIONS_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when table updated"""
    table_uid: builtins.str
    """The updated table uid"""
    @property
    def table(self) -> agent.agent.v1alpha.table_pb2.Table:
        """The updated table"""
    @property
    def column_definitions(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, agent.agent.v1alpha.table_pb2.ColumnDefinition]:
        """The updated column definitions"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        table_uid: builtins.str = ...,
        table: agent.agent.v1alpha.table_pb2.Table | None = ...,
        column_definitions: collections.abc.Mapping[builtins.str, agent.agent.v1alpha.table_pb2.ColumnDefinition] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "table", b"table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_definitions", b"column_definitions", "create_time", b"create_time", "table", b"table", "table_uid", b"table_uid"]) -> None: ...

global___ChatTableUpdatedEvent = ChatTableUpdatedEvent

@typing_extensions.final
class ChatErrorUpdatedEvent(google.protobuf.message.Message):
    """ChatErrorUpdatedEvent represents an event for an error"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ERROR_TYPE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when error triggered"""
    error_type: builtins.str
    """The error type"""
    error: builtins.str
    """The error message"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error_type: builtins.str = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "error", b"error", "error_type", b"error_type"]) -> None: ...

global___ChatErrorUpdatedEvent = ChatErrorUpdatedEvent

@typing_extensions.final
class ChatDebugOutputUpdatedEvent(google.protobuf.message.Message):
    """ChatDebugOutputUpdatedEvent represents an event for debug log"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DEBUG_OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when debug log output"""
    debug_output: builtins.str
    """The debug output"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        debug_output: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "debug_output", b"debug_output"]) -> None: ...

global___ChatDebugOutputUpdatedEvent = ChatDebugOutputUpdatedEvent

@typing_extensions.final
class ChatEndedEvent(google.protobuf.message.Message):
    """ChatEndedEvent represents an event when chat ends"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_TIME_FIELD_NUMBER: builtins.int
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when chat ends"""
    def __init__(
        self,
        *,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time"]) -> None: ...

global___ChatEndedEvent = ChatEndedEvent
